""" This module provides functions to convert PDF to text strings."""

def convert(path):
    """
    Convert the given PDF to text.
    
    Parameters:
    path(str): The path to a PDF file.

    Returns:
    str: The content of the PDF file as text.
    """
    print("As mentioned just learning to build and test package")